# Mongolian to IPA
This project remains incomplete and is not suitable for production use.

## Install
```bash
pip install mongolian2ipa
```

## Usage
```python
from mongolian2ipa import mongolian2ipa

result = mongolian2ipa('сайн уу')
print(result)  # sæːn.oː
```